@@ -1,16 +1,18 @@
+use 5.008;
+use strict;
+use warnings;
+
 package Data::Conveyor::Ticket::Payload;
+our $VERSION = '1.100870';
+# ABSTRACT: Stage-based conveyor-belt-like ticket handling system
 
 # ptags: DCTP
-# $Id: Payload.pm 13653 2007-10-22 09:11:20Z gr $
 #
 # This class houses the ticket payload objects
-use warnings;
-use strict;
 use Error::Hierarchy::Util 'assert_defined';
 use Data::Miscellany 'flatten';
 use once;
-our $VERSION = '0.11';
-use base qw(
+use parent qw(
   Class::Scaffold::Storable
   Class::Scaffold::HierarchicalDirty
 );
@@ -109,6 +111,10 @@ sub add_items_from_list {
     my $self = shift;
     for my $item (flatten(@_)) {
         (my $factory_type = $item->get_my_factory_type) =~ s/^payload_//;
+        if ($factory_type eq 'common') {
+            $self->common($item);
+            next;
+        }
         my $list_accessor = $self->get_list_name_for_object_type($factory_type);
         my $push_method   = $list_accessor . '_push';
         $self->$push_method($item);
@@ -305,200 +311,140 @@ sub apply_instruction_containers {
 # code.
 sub upgrade { }
 1;
+
+
 __END__
+=pod
+
+=for stopwords rc
 
 =head1 NAME
 
-Data::Conveyor::Ticket::Payload - stage-based conveyor-belt-like ticket handling system
+Data::Conveyor::Ticket::Payload - Stage-based conveyor-belt-like ticket handling system
 
-=head1 SYNOPSIS
+=head1 VERSION
 
-    Data::Conveyor::Ticket::Payload->new;
-
-=head1 DESCRIPTION
-
-None yet. This is an early release; fully functional, but undocumented. The
-next release will have more documentation.
+version 1.100870
 
 =head1 METHODS
 
-=over 4
+=head2 LIST_ACCESSOR_FOR_OBJECT_TYPE
 
+FIXME
 
+=head2 add_items_from_list
 
-=back
+FIXME
 
-Data::Conveyor::Ticket::Payload inherits from L<Class::Scaffold::Storable>
-and L<Class::Scaffold::HierarchicalDirty>.
+=head2 apply_instruction_containers
 
-The superclass L<Class::Scaffold::Storable> defines these methods and
-functions:
+FIXME
 
-    MUNGE_CONSTRUCTOR_ARGS(), clear_storage_info(), clear_storage_type(),
-    delete_storage_info(), exists_storage_info(), id(),
-    keys_storage_info(), storage(), storage_info(), storage_info_clear(),
-    storage_info_delete(), storage_info_exists(), storage_info_keys(),
-    storage_info_values(), storage_type(), storage_type_clear(),
-    values_storage_info()
+=head2 check
 
-The superclass L<Class::Scaffold::Base> defines these methods and
-functions:
+FIXME
 
-    new(), FIRST_CONSTRUCTOR_ARGS(), add_autoloaded_package(), log()
+=head2 clear_all_exceptions
 
-The superclass L<Data::Inherited> defines these methods and functions:
+FIXME
 
-    every_hash(), every_list(), flush_every_cache_by_key()
+=head2 delete_exceptions_by_uuid
 
-The superclass L<Data::Comparable> defines these methods and functions:
+FIXME
 
-    comparable(), comparable_scalar(), dump_comparable(),
-    yaml_dump_comparable()
+=head2 delete_implicit_items
 
-The superclass L<Class::Scaffold::Delegate::Mixin> defines these methods
-and functions:
+FIXME
 
-    delegate()
+=head2 filter_exceptions_by_rc
 
-The superclass L<Class::Scaffold::Accessor> defines these methods and
-functions:
+FIXME
 
-    mk_framework_object_accessors(), mk_framework_object_array_accessors(),
-    mk_readonly_accessors()
+=head2 filter_exceptions_by_status
 
-The superclass L<Class::Accessor::Complex> defines these methods and
-functions:
+FIXME
 
-    mk_abstract_accessors(), mk_array_accessors(), mk_boolean_accessors(),
-    mk_class_array_accessors(), mk_class_hash_accessors(),
-    mk_class_scalar_accessors(), mk_concat_accessors(),
-    mk_forward_accessors(), mk_hash_accessors(), mk_integer_accessors(),
-    mk_new(), mk_object_accessors(), mk_scalar_accessors(),
-    mk_set_accessors(), mk_singleton()
+=head2 generate_add_method
 
-The superclass L<Class::Accessor> defines these methods and functions:
+FIXME
 
-    _carp(), _croak(), _mk_accessors(), accessor_name_for(),
-    best_practice_accessor_name_for(), best_practice_mutator_name_for(),
-    follow_best_practice(), get(), make_accessor(), make_ro_accessor(),
-    make_wo_accessor(), mk_accessors(), mk_ro_accessors(),
-    mk_wo_accessors(), mutator_name_for(), set()
+=head2 get_all_exceptions
 
-The superclass L<Class::Accessor::Installer> defines these methods and
-functions:
+FIXME
 
-    install_accessor()
+=head2 get_list_for_object_type
 
-The superclass L<Class::Accessor::Constructor> defines these methods and
-functions:
+FIXME
 
-    _make_constructor(), mk_constructor(), mk_constructor_with_dirty(),
-    mk_singleton_constructor()
+=head2 get_list_name_for_object_type
 
-The superclass L<Class::Accessor::FactoryTyped> defines these methods and
-functions:
+FIXME
 
-    clear_factory_typed_accessors(), clear_factory_typed_array_accessors(),
-    count_factory_typed_accessors(), count_factory_typed_array_accessors(),
-    factory_typed_accessors(), factory_typed_accessors_clear(),
-    factory_typed_accessors_count(), factory_typed_accessors_index(),
-    factory_typed_accessors_pop(), factory_typed_accessors_push(),
-    factory_typed_accessors_set(), factory_typed_accessors_shift(),
-    factory_typed_accessors_splice(), factory_typed_accessors_unshift(),
-    factory_typed_array_accessors(), factory_typed_array_accessors_clear(),
-    factory_typed_array_accessors_count(),
-    factory_typed_array_accessors_index(),
-    factory_typed_array_accessors_pop(),
-    factory_typed_array_accessors_push(),
-    factory_typed_array_accessors_set(),
-    factory_typed_array_accessors_shift(),
-    factory_typed_array_accessors_splice(),
-    factory_typed_array_accessors_unshift(),
-    index_factory_typed_accessors(), index_factory_typed_array_accessors(),
-    mk_factory_typed_accessors(), mk_factory_typed_array_accessors(),
-    pop_factory_typed_accessors(), pop_factory_typed_array_accessors(),
-    push_factory_typed_accessors(), push_factory_typed_array_accessors(),
-    set_factory_typed_accessors(), set_factory_typed_array_accessors(),
-    shift_factory_typed_accessors(), shift_factory_typed_array_accessors(),
-    splice_factory_typed_accessors(),
-    splice_factory_typed_array_accessors(),
-    unshift_factory_typed_accessors(),
-    unshift_factory_typed_array_accessors()
+=head2 get_transactions_with_data_object_type
 
-The superclass L<Class::Scaffold::Factory::Type> defines these methods and
-functions:
+FIXME
 
-    factory_log()
+=head2 get_transactions_with_data_object_type_and_cmd
 
-The superclass L<Class::Factory::Enhanced> defines these methods and
-functions:
+FIXME
 
-    add_factory_type(), make_object_for_type(), register_factory_type()
+=head2 prepare_comparable
 
-The superclass L<Class::Factory> defines these methods and functions:
+FIXME
 
-    factory_error(), get_factory_class(), get_factory_type_for(),
-    get_loaded_classes(), get_loaded_types(), get_my_factory(),
-    get_my_factory_type(), get_registered_class(),
-    get_registered_classes(), get_registered_types(),
-    remove_factory_type(), unregister_factory_type()
+=head2 rc
 
-The superclass L<Class::Accessor::Constructor::Base> defines these methods
-and functions:
+FIXME
 
-    STORE(), clear_dirty(), clear_hygienic(), clear_unhygienic(),
-    contains_hygienic(), contains_unhygienic(), delete_hygienic(),
-    delete_unhygienic(), dirty(), dirty_clear(), dirty_set(),
-    elements_hygienic(), elements_unhygienic(), hygienic(),
-    hygienic_clear(), hygienic_contains(), hygienic_delete(),
-    hygienic_elements(), hygienic_insert(), hygienic_is_empty(),
-    hygienic_size(), insert_hygienic(), insert_unhygienic(),
-    is_empty_hygienic(), is_empty_unhygienic(), set_dirty(),
-    size_hygienic(), size_unhygienic(), unhygienic(), unhygienic_clear(),
-    unhygienic_contains(), unhygienic_delete(), unhygienic_elements(),
-    unhygienic_insert(), unhygienic_is_empty(), unhygienic_size()
+=head2 status
 
-The superclass L<Tie::StdHash> defines these methods and functions:
+FIXME
 
-    CLEAR(), DELETE(), EXISTS(), FETCH(), FIRSTKEY(), NEXTKEY(), SCALAR(),
-    TIEHASH()
+=head2 update_transaction_stati
+
+FIXME
+
+=head2 upgrade
+
+FIXME
+
+=head1 INSTALLATION
+
+See perlmodinstall for information and options on installing Perl modules.
 
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Conveyor>.
 
 =head1 AVAILABILITY
 
 The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see
+L<http://search.cpan.org/dist/Data-Conveyor/>.
+
+The development version lives at
+L<http://github.com/hanekomu/Data-Conveyor/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
 
 =head1 AUTHORS
 
-Florian Helmberger C<< <fh@univie.ac.at> >>
-
-Achim Adam C<< <ac@univie.ac.at> >>
-
-Mark Hofstetter C<< <mh@univie.ac.at> >>
-
-Heinz Ekker C<< <ek@univie.ac.at> >>
-
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+  Marcel Gruenauer <marcel@cpan.org>
+  Florian Helmberger <fh@univie.ac.at>
+  Achim Adam <ac@univie.ac.at>
+  Mark Hofstetter <mh@univie.ac.at>
+  Heinz Ekker <ek@univie.ac.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2009 by the authors.
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This software is copyright (c) 2004 by Marcel Gruenauer.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
